package Protocol::SPDY::Frame::Control::SynStream;
{
  $Protocol::SPDY::Frame::Control::SynStream::VERSION = '0.999_007';
}
use strict;
use warnings;

=head1 NAME

Protocol::SPDY::Frame::Control::SynStream - obsolete, replaced by L<Protocol::SPDY::Frame::Control::SYN_STREAM>

=head1 VERSION

version 0.999_007

=head1 DESCRIPTION

See L<Protocol::SPDY> and L<Protocol::SPDY::Base>.

=cut

1;

=head1 AUTHOR

Tom Molesworth <cpan@entitymodel.com>

=head1 LICENSE

Copyright Tom Molesworth 2011-2012. Licensed under the same terms as Perl itself.
